@@ -27,21 +27,27 @@ pip install cloudcomponents.cdk-contentful-webhook
 ## How to use
 
 ```python
-import { RestApi } from '@aws-cdk/aws-apigateway';
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
 import { ContentfulWebhook } from '@cloudcomponents/cdk-contentful-webhook';
 import { SecretKey } from '@cloudcomponents/cdk-secret-key';
+import { Stack, StackProps, aws_apigateway } from 'aws-cdk-lib';
+import { Construct } from 'constructs';
 
 export class ContentfulWebhookStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
     super(scope, id, props);
 
-    const api = new RestApi(this, 'Endpoint');
+    const api = new aws_apigateway.RestApi(this, 'Endpoint');
     api.root.addMethod('POST');
 
-    const accessToken = SecretKey.fromPlainText(process.env.ACCESS_TOKEN as string);
+    if (typeof process.env.ACCESS_TOKEN === 'undefined') {
+      throw new Error('environment variable ACCESS_TOKEN undefined');
+    }
+    const accessToken = SecretKey.fromPlainText(process.env.ACCESS_TOKEN);
 
-    const spaceId = process.env.SPACE_ID as string;
+    if (typeof process.env.SPACE_ID === 'undefined') {
+      throw new Error('environment variable SPACE_ID undefined');
+    }
+    const spaceId = process.env.SPACE_ID;
 
     const topics = ['Entry.create'];
 
@@ -81,18 +87,18 @@ import typing_extensions
 
 from ._jsii import *
 
-import aws_cdk.core
 import cloudcomponents.cdk_secret_key
+import constructs
 
 
 class ContentfulWebhook(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-contentful-webhook.ContentfulWebhook",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         access_token: typing.Union[builtins.str, cloudcomponents.cdk_secret_key.SecretKey],
